@@ -33,9 +33,9 @@ def arg_parser():
     parser.add_argument('-s', '--slack', action='store_true', help='Send the logs to IT/DevOps Slack channel')
 
     # arguments for upload
-    parser.add_argument('-t', "--type", help="radar type")
-    parser.add_argument('-n', "--number", help="version number of the software")
-    parser.add_argument('-p', "--path", help="upload file absolute path")
+    parser.add_argument('-t', "--type", type=str, help="radar type")
+    parser.add_argument('-n', "--number", type=str, help="version of the software")
+    parser.add_argument('-p', "--path", type=str, help="upload file absolute path")
 
     args = parser.parse_args()
     config = yaml_parser.parse_config()
