@@ -56,7 +56,7 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
-                used_config_file(cfg_file)
+                print_used_config_file(cfg_file)
                 # file_path = os.path.abspath(cfg_file)
                 # print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
@@ -79,11 +79,12 @@ def parse_config():
 
     return config
 
-def used_config_file(cfg_file):
-    # do not print it out multiple times
-    if cfg_file == used_config_file.last_cfg_file:
-        return
-    used_config_file.last_cfg_file = cfg_file
-    print(f"Config file found at {cfg_file}")
-used_config_file.last_cfg_file = None
-    
\ No newline at end of file
+def print_used_config_file(cfg_file):
+    """
+    Print the path of the used config file if it has not been printed before
+    """
+    if print_used_config_file.last_cfg_file != cfg_file:
+        print(f"Using config file: {cfg_file}")
+        print_used_config_file.last_cfg_file = cfg_file
+
+print_used_config_file.last_cfg_file = None
